%% FIGURE 9 -- BACCALA ET AL. (2016) DTF: UNIFIED ASYMPTOTIC THEORY
% DESCRIPTION:
%
% Routine *figure9_example3_idtf_ns2000.m* publish
%
% Linear five-dimensional  VAR(2) model
% 
% LA Baccala, DY Takahashi, K Sameshima (2016) Directed Transfer 
% Function: Unified Asymptotic Theory and Some of its Implications. 
% _IEEE Transactions on Biomedical Engineering_ *PP*.
% 
% <http://dx.doi.org/10.1109/TBME.2016.2550199> 
% 
% Example 3: Asymptotic DTF:  Example 3 5-VAR model - open / closed loop.
% 
%                     x1 ==> x2 ==> x3 ==> x4 <==> x5
%                      ^--------------------------/
%
%                       *This is the close loop model.*

%% Generating data set for analysis
%
clear; clc; format compact
flgPlotStyle = 'Print'; % or 'Screen' mode
flgRandomize = 0;  % Generate the specific data set used in Fig. 9.
ns = 2000;         % number of sample points
nDiscard = 20000;  % number of points discarded at beginning of simulation
p = 2;             % model order

if (exist('figure9_example3_idtf_ns2000.mat') == 2) & is_octave & ~flgRandomize,
   load figure9_example3_idtf_ns2000
else
   [u] = fbaccala2016_example3( ns, nDiscard, flgRandomize );
   if ~is_octave & ~flgRandomize,
      save figure9_example3_idtf_ns2000 u
   end;
end;

chLabels = [];    % Using default labeling schema for channel identification

%% Equation (11)
%
% <<example3_equation.png>>
%
% *Equation (11) from Baccala et al. _IEEE Trans Biomed Engin._, 2016.*
%

%% Connectivity diagram
%
% <<example3_figure8.png>>
%
% *Example 3 loop connectivity structure following (11). Signals from any structure reach all other structures. from Baccala et al. _IEEE Trans Biomed Engin._, 2016.*

%%
% *Data pre-processing: detrending and normalization options*


flgDetrend = 1;     % Detrending the data set
flgStandardize = 0; % No standardization
[nChannels,nSegLength] = size(u);
if nChannels > nSegLength, u = u.';
   [nChannels,nSegLength] = size(u);
end;
if flgDetrend,
   for i=1:nChannels, u(i,:) = detrend(u(i,:)); end;
   disp('Time series were detrended.');
end;
if flgStandardize,
   for i=1:nChannels, u(i,:) = u(i,:)/std(u(i,:)); end;
   disp('Time series were scale-standardized.');
end;

%% 
% *MVAR model estimation*

maxIP = 30;         % maximum model order to consider.
alg = 1;            % 1: Nutall-Strand MVAR estimation algorithm
criterion = 1;      % 1: AIC, Akaike Information Criteria
disp('Running MVAR estimation and GCT analysis routines.')
[IP,pf,A,pb,B,ef,eb,vaic,Vaicv] = mvar(u,maxIP,alg,criterion);
disp(['Number of channels = ' int2str(nChannels) ' with ' ...
   int2str(nSegLength) ' data points; MAR model order = ' int2str(IP) '.']);

%%
% *Testing for adequacy of MAR model fitting through Portmanteau test*

h = 20; % testing lag
MVARadequacy_signif = 0.05; % VAR model estimation adequacy significance
                            % level
aValueMVAR = 1 - MVARadequacy_signif; % Confidence value for the testing
flgPrintResults = 1;

%%
% Granger causality test (GCT) and instantaneous GCT

gct_signif  = 0.01;  % Granger causality test significance level
igct_signif = 0.01;  % Instantaneous GCT significance level
flgPrintResults = 1;
[Tr_gct, pValue_gct, Tr_igct, pValue_igct] = gct_alg(u,A,pf,gct_signif, ...
                                              igct_signif,flgPrintResults);

%% DTF estimation
%
% DTF analysis results are saved in *c* structure.
% See asymp_dtf.m or issue 
%   >> help asymp_dtf 
% command for more detail.

metric = 'info';  % euc  = original PDC or DTF;
                 % diag = generalized PDC (gPDC) or directed coherence (DC);
                 % info = information PDC (iPDC) or iDTF.

nFreqs = 128;
alpha = 0.01;

c = asymp_dtf(u,A,pf,nFreqs,metric,alpha);

%%
% $|_{i}DTF(\lambda)|^2$ Matrix Layout Plotting

switch lower(flgPlotStyle)
   case 'print'
      flgColor =[0];      % white background
      flgMax = 'TCI';
      flgSignifColor = 1; % black + gray
      flgScale = 3;       % [0 max(flgMax)]
   otherwise % 'screen'
      flgColor =[1];      % Colored background
      flgMax = 'TCI';
      flgSignifColor = 3; % red + green
      flgScale = 2;       % [0 1]/[0 .1]/[0 .01]
end;

% ---------------Plotting options flag setting-----------------------------
%           [1 2 3 4 5 6 7]
flgPrinting=[1 1 1 2 2 0 1];
%            | | | | | | 7 Spectra(0: w/o SS; 1: Linear; 2: log-scale)
%            | | | | | 6 Coherence
%            | | | | 5 Plot lower confidence limit (legacy)
%            | | | 4 Plot upper confidence limit
%            | | 3 Significant DTF(w) in red line  (legacy)
%            | 2 Patnaik threshold level in black dashed-line
%            1 plot DTF
%--------------------------------------------------------------------------

fs = 1;       % sampling frequency

w = fs*(0:(nFreqs-1))/2/nFreqs;
w_max = fs/2;

h=figure;
set(h,'NumberTitle','off','MenuBar','none', ...
      'Name','[Asymptotic DTF] Fig 9. Example 3 - iDTF, ns = 2000')

[hxlabel hylabel] = xplot(c,...
   flgPrinting,fs,w_max,chLabels,flgColor,flgScale,flgMax,flgSignifColor);

%xplot_title(alpha, metric, measure(c));
 
[ax,hT]=suplabel(['Example 3 - Five-VAR Closed-Loop: ns = ' ...
   int2str(ns) ' data points; p = ' int2str(c.p) '; \alpha = ' ...
   int2str(100*alpha) '%.'],'t');
set(hT,'FontSize',10); % Subtitle font size

drawnow
%%
% *Uncomment the command line bellow to generate an eps output file*
%
% % print -depsc2 -painters Fig9_example3_idtf_ns2000.eps


%% Figure depicted in the article Baccala et al (2016) 
% Figure 9, deproduced from article.
%
% <<example3_figure9.png>>
% 

%% Some remarks:
%
% # As usual, figure 9 underwent some cosmetic edit
%   and addition of a inlet graph
%%
% This completes the *Figure 9* generation (Baccala et al, 2016)'


